@@ -4,7 +4,7 @@ from rich import print as rprint
 from rich.box import ROUNDED
 from rich.panel import Panel
 
-from ..runner import AgaProblemOutput
+from ..runner import ProblemOutput
 
 RICH_PANEL_OPTS = {
     "box": ROUNDED,
@@ -13,7 +13,7 @@ RICH_PANEL_OPTS = {
 }
 
 
-def print_fancy_summary(output: AgaProblemOutput) -> None:
+def print_fancy_summary(output: ProblemOutput) -> None:
     """Print a fancy summary of the problem."""
     rprint(
         Panel(
@@ -25,11 +25,11 @@ def print_fancy_summary(output: AgaProblemOutput) -> None:
     )
 
     for test in output.tests:
-        if test.output and not test.hidden:
+        if not test.hidden:
             rprint(
                 Panel(
-                    test.output,
-                    title="" if test.correct() else "[bright_red]" + test.name,
+                    test.output or "",
+                    title=("" if test.is_correct() else "[bright_red]") + test.name,
                     subtitle=f"{test.score}/{test.max_score}",
                     **RICH_PANEL_OPTS,  # type: ignore
                 )
